# Clara Pip Package

Enables easy inclusion of the Clara system. For full customizability, setup from
the [main GitHub](https://github.com/huberf/clara-bot).

## Setup (With Pip)
* Run `pip install clara`
* Create a new directory and enter it such as `mkdir clara`
* Run `clara` and you can now run `python3 chat.py` to being.
